<?php
/**
 * Directory Gadget
 *
 * @category    Gadget
 * @package     Directory
 */
class Directory_Actions_Admin_Files extends Jaws_Gadget_Action
{
    /**
     * Builds the file management form
     *
     * @access  public
     * @return  string  XHTML form
     */
    function FileForm()
    {
        $mode = $this->gadget->request->fetch('mode');
        if ($mode === null) $mode = 'view';
        $tpl = $this->gadget->template->loadAdmin('File.html');
        $tpl->SetBlock($mode);
        $tpl->SetVariable('lbl_title', $this::t('FILE_TITLE'));
        $tpl->SetVariable('lbl_desc', $this::t('FILE_DESC'));
        $tpl->SetVariable('lbl_tags', $this::t('FILE_TAGS'));
        $tpl->SetVariable('lbl_published', Jaws::t('PUBLISHED'));
        $tpl->SetVariable('lbl_url', $this::t('FILE_URL'));
        $tpl->SetVariable('lbl_thumbnail', $this::t('THUMBNAIL'));
        $tpl->SetVariable('lbl_cancel', Jaws::t('CANCEL'));
        if ($mode === 'edit') {
            $editor =& $this->app->loadEditor('Directory', 'description');
            $editor->TextArea->SetStyle('width:100%; height:60px;');
            $tpl->SetVariable('description', $editor->get());
            $tpl->SetVariable('lbl_file', $this::t('FILE'));
            $tpl->SetVariable('lbl_ok', Jaws::t('OK'));
        } else {
            $tpl->SetVariable('lbl_filename', $this::t('FILE_FILENAME'));
            $tpl->SetVariable('lbl_type', $this::t('FILE_TYPE'));
            $tpl->SetVariable('lbl_size', $this::t('FILE_SIZE'));
            $tpl->SetVariable('lbl_bytes', $this::t('BYTES'));
            $tpl->SetVariable('lbl_created', $this::t('FILE_CREATED'));
            $tpl->SetVariable('lbl_modified', $this::t('FILE_MODIFIED'));
            $tpl->SetVariable('title', '{title}');
            $tpl->SetVariable('desc', '{description}');
            $tpl->SetVariable('tags', '{tags}');
            $tpl->SetVariable('user_filename', '{user_filename}');
            $tpl->SetVariable('type', '{type}');
            $tpl->SetVariable('mime_type', '{mime_type}');
            $tpl->SetVariable('size', '{size}');
            $tpl->SetVariable('file_size', '{file_size}');
            $tpl->SetVariable('link', '{link}');
            $tpl->SetVariable('create_time', '{create_time}');
            $tpl->SetVariable('update_time', '{update_time}');
            $tpl->SetVariable('created', '{created}');
            $tpl->SetVariable('modified', '{modified}');
        }

        $tpl->ParseBlock($mode);
        return $tpl->Get();
    }

    /**
     * Updates file
     *
     * @access  public
     * @return  array   Response array
     */
    function SaveFile()
    {
        $data = $this->gadget->request->fetch(
            array(
                'id', 'parent', 'title', 'description', 'public', 'published',
                'user_filename', 'host_filename', 'mime_type', 'file_size', 'thumbnail',
                'tags'
            )
        );

        if (!empty($data['title'])) {
            $result = $this->gadget->model->loadAdmin('Files')->SaveFile($data);
        } else {
            $result = Jaws_Error::raiseError($this::t('ERROR_INCOMPLETE_DATA'), __FUNCTION__);
        }

        if (Jaws_Error::IsError($result)) {
            return $this->gadget->session->response(
                $result->getMessage(),
                RESPONSE_ERROR
            );
        } else {
            return $this->gadget->session->response(
                $result,
                RESPONSE_NOTICE
            );
        }
    }

    /**
     * Generates file download URL
     *
     * @access  public
     * @return  string  Related URL
     */
    function GetDownloadURL($id = null)
    {
        if ($id === null) {
            $id = (int)$this->gadget->request->fetch('id');
        }
        return $this->gadget->urlMap(
            'Download',
            array('id' => $id),
            array('absolute' => true)
        );
    }

    /**
     * Reads text file content
     *
     * @access  public
     * @return  string  Textual content
     */
    function GetFileContent($id)
    {
        $file = $this->gadget->model->load('Files')->GetFile($id);
        if (Jaws_Error::IsError($file) || empty($file) || empty($file['host_filename'])) {
            return;
        }
        $filename = ROOT_DATA_PATH . 'directory/' . $file['host_filename'];
        if (!Jaws_FileManagement_File::file_exists($filename)) {
            return;
        }

        return Jaws_FileManagement_File::file_get_contents($filename);
    }

    /**
     * Builds HTML5 audio/video tags for the file
     *
     * @access  public
     * @return  array   Response array
     */
    function PlayMedia($file = null)
    {
        if (empty($file) || !isset($file['host_filename'])) {
            $id = (int)$this->gadget->request->fetch('id');
            $file = $this->gadget->model->load('Files')->GetFile($id);
            if (Jaws_Error::IsError($file) || empty($file) || empty($file['host_filename'])) {
                return false;
            }
        }

        $block = '';
        $type = $this->gadget->model->load('Files')->getFileType($file['host_filename']);
        switch ($type) {
            case Directory_Info::FILE_TYPE_TEXT:
                $block = 'text';
                break;
            case Directory_Info::FILE_TYPE_IMAGE:
                $block = 'image';
                break;
            case Directory_Info::FILE_TYPE_AUDIO:
                $block = 'audio';
                break;
            case Directory_Info::FILE_TYPE_VIDEO:
                $block = 'video';
                break;
            default:
                return false;
        }

        $tpl = $this->gadget->template->loadAdmin('Media.html');
        $tpl->SetBlock($block);
        if ($type === Directory_Info::FILE_TYPE_TEXT) {
            $filename = ROOT_DATA_PATH . 'directory/' . $file['host_filename'];
            if (Jaws_FileManagement_File::file_exists($filename)) {
                $tpl->SetVariable('text', Jaws_FileManagement_File::file_get_contents($filename));
            }
        } else {
            $tpl->SetVariable('url', $this->gadget->urlMap('Download', array('id' => $file['id'])));
        }

        $tpl->ParseBlock($block);
        return $this->gadget->plugin->parse($tpl->get());
    }

    /**
     * Uploads file to system temp directory
     *
     * @access  public
     * @return  string  JavaScript snippet
     */
    function UploadFile()
    {
        $response = array();
        $type = $this->gadget->request->fetch('type', 'post');
        $dirPath = ROOT_DATA_PATH . 'directory';
        if (!is_dir($dirPath)) {
            if (!Jaws_FileManagement_File::mkdir($dirPath)) {
                $response = array(
                    'type' => 'error',
                    'message' =>$this::t('ERROR_FILE_UPLOAD')
                );
            }
        }

        if (empty($response)) {
            $res = Jaws_FileManagement_File::uploadFiles($_FILES, $dirPath, '', null);
            if (Jaws_Error::IsError($res)) {
                $response = array('type' => 'error',
                                  'message' => $res->getMessage());
            } else {
                $response = array('type' => 'notice',
                                  'user_filename' => $res['file'][0]['user_filename'],
                                  'host_filename' => $res['file'][0]['host_filename'],
                                  'mime_type' => $res['file'][0]['host_mimetype'],
                                  'file_size' => $res['file'][0]['host_filesize'],
                                  'upload_type' => $type);
            }
        }

        $response = Jaws_UTF8::json_encode($response);
        return "<script>parent.onUpload($response);</script>";
    }
}