<?php
/**
 * Filebrowser Admin Gadget
 *
 * @category   GadgetAdmin
 * @package    FileBrowser
 * @author     Jonathan Hernandez <ion@suavizado.com>
 * @author     Pablo Fischer <pablo@pablo.com.mx>
 * @author     Ali Fazelzadeh <afz@php.net>
 * @copyright   2004-2024 Jaws Development Group
 * @license    http://www.gnu.org/copyleft/gpl.html
 */
class FileBrowser_Actions_Admin_Files extends Jaws_Gadget_Action
{
    /**
     * Show Admin action
     *
     * @access  public
     * @return  string  XHTML template content
     */
    function Files()
    {
        $this->AjaxMe('script.js');

        $dHTML = $this->gadget->action->loadAdmin('Directory');

        $tpl = $this->gadget->template->loadAdmin('FileBrowser.html');
        $tpl->SetBlock('filebrowser');
        $tpl->SetVariable('base_script', BASE_SCRIPT . '?reqGadget=FileBrowser&reqAction=Files');

        $path = $this->gadget->request->fetch('path', 'get');
        $path = empty($path)? '/' : $path;
        $tpl->SetVariable('path', $path);
        $this->gadget->define('path', $path);

        $tpl->SetVariable('lbl_location', $this::t('LOCATION'));
        $tpl->SetVariable('location_link', $this->GetLocation($path));

        $orderType =& Piwi::CreateWidget('Combo', 'order_type');
        $orderType->AddOption(Jaws::t('TITLE') . ' &darr;', 'title, false');
        $orderType->AddOption(Jaws::t('TITLE') . ' &uarr;', 'title, true');
        $orderType->AddOption($this::t('FILENAME') . ' &darr;', 'filename, false');
        $orderType->AddOption($this::t('FILENAME') . ' &uarr;', 'filename, true');
        $orderType->AddOption(Jaws::t('DATE') . ' &darr;', 'date, false');
        $orderType->AddOption(Jaws::t('DATE') . ' &uarr;', 'date, true');
        $orderType->SetDefault('filename, false');
        $orderType->AddEvent(ON_CHANGE, 'javascript:reOrderFiles();');
        $tpl->SetVariable('lbl_order', $this::t('ORDER_BY'));
        $tpl->SetVariable('order_type', $orderType->Get());

        $tpl->SetVariable('lbl_file',      $this::t('FILE'));
        $tpl->SetVariable('lbl_directory', $this::t('DIR'));
        $tpl->SetVariable('fui',  $this->GetFileUI());
        $tpl->SetVariable('dui',  $dHTML->GetDirectoryUI());
        $tpl->SetVariable('grid', $this->Datagrid($path));

        $this->gadget->define('incompleteFields', Jaws::t('ERROR_INCOMPLETE_FIELDS'));
        $this->gadget->define('confirmFileDelete', $this::t('CONFIRM_DELETE_FILE'));
        $this->gadget->define('confirmDirDelete',  $this::t('CONFIRM_DELETE_DIR'));

        $tpl->ParseBlock('filebrowser');
        return $tpl->Get();
    }

   /**
     * Show a form to edit a given file
     *
     * @access  public
     * @return  string  XHTML template content
     */
    function GetFileUI()
    {
        $tpl = $this->gadget->template->loadAdmin('FileBrowser.html');
        $tpl->SetBlock('file_ui');

        $upload_switch =& Piwi::CreateWidget('CheckButtons', 'upload_switch');
        $upload_switch->AddEvent(ON_CLICK, 'javascript:uploadswitch(this.checked);');
        $upload_switch->AddOption($this::t('UPLOAD_FILE'), '0', 'upload_switch', true);
        $tpl->SetVariable('upload_switch', $upload_switch->Get());

        $filename =& Piwi::CreateWidget('Entry', 'filename', '');
        $filename->SetID('filename');
        $filename->SetStyle('width: 270px;');
        $tpl->SetVariable('lbl_filename', $this::t('FILENAME'));
        $tpl->SetVariable('filename', $filename->Get());

        $uploadfile =& Piwi::CreateWidget('FileEntry', 'uploadfile', '');
        $uploadfile->SetID('uploadfile');
        $uploadfile->SetStyle('width: 270px;');
        $tpl->SetVariable('uploadfile', $uploadfile->Get());

        $tpl->SetVariable('lbl_title', Jaws::t('TITLE'));
        $title =& Piwi::CreateWidget('Entry', 'file_title', '');
        $title->SetStyle('width: 270px;');
        $tpl->SetVariable('title', $title->Get());

        $desc =& Piwi::CreateWidget('TextArea', 'file_description', '');
        $desc->SetID('file_description');
        $desc->SetRows(5);
        $desc->SetStyle('width: 270px;');
        $tpl->SetVariable('lbl_description', Jaws::t('DESCRIPTION'));
        $tpl->SetVariable('description', $desc->Get());

        $tpl->SetVariable('lbl_fast_url', $this::t('FASTURL'));
        $fasturl =& Piwi::CreateWidget('Entry', 'file_fast_url', '');
        $fasturl->SetStyle('direction:ltr; width:270px;');
        $tpl->SetVariable('fast_url', $fasturl->Get());

        if ($this->gadget->GetPermission('ManageFiles')) {
            $btnSave =& Piwi::CreateWidget('Button', 'btn_save', Jaws::t('SAVE'), STOCK_SAVE);
            $btnSave->AddEvent(ON_CLICK, "javascript:saveFile();");
            $tpl->SetVariable('btn_save', $btnSave->Get());
        }

        $btnCancel =& Piwi::CreateWidget('Button', 'btn_cancel', Jaws::t('CANCEL'), STOCK_CANCEL);
        $btnCancel->AddEvent(ON_CLICK, "javascript:stopAction('file');");
        $tpl->SetVariable('btn_cancel', $btnCancel->Get());

        $tpl->ParseBlock('file_ui');
        return $tpl->Get();
    }

    /**
     * Builds the basic datagrid view
     *
     * @access  public
     * @param   string  $path
     * @return  string  XHTML template of datagrid
     */
    function DataGrid($path = '')
    {
        $model = $this->gadget->model->load('Directory');
        $total = $model->GetDirContentsCount($path);

        $grid =& Piwi::CreateWidget('DataGrid', array());
        $grid->TotalRows($total);
        $grid->pageBy(15);
        $grid->SetID('fb_datagrid');
        $column = Piwi::CreateWidget('Column', '');
        $column->SetStyle('width: 1px;');
        $grid->AddColumn($column);
        $grid->AddColumn(Piwi::CreateWidget('Column', Jaws::t('TITLE')));
        $grid->AddColumn(Piwi::CreateWidget('Column', Jaws::t('NAME')));
        $grid->AddColumn(Piwi::CreateWidget('Column', $this::t('SIZE')));
        $grid->AddColumn(Piwi::CreateWidget('Column', $this::t('HITS')));
        $grid->AddColumn(Piwi::CreateWidget('Column', Jaws::t('ACTIONS')));
        $grid->SetStyle('width: 100%;');

        return $grid->Get();
    }

    /**
     * Creates and returns some data
     *
     * @access  public
     * @param   string  $path   
     * @return  string  location link string   
     */
    function GetLocation($path)
    {
        $model = $this->gadget->model->load('Directory');

        $dir_array = $model->GetCurrentRootDir($path);
        $path_link = '';
        $location_link = '';
        foreach ($dir_array as $d) {
            $path_link .= $d . (($d != '/')? '/' : '');
            $link =& Piwi::CreateWidget('Link', $d, "javascript:cwd('{$path_link}');");
            $location_link .= $link->Get() . '&nbsp;';
        }

        return $location_link;
    }

    /**
     * Uploads a new file
     *
     * @access  public
     */
    function UploadFile()
    {
        $this->gadget->CheckPermission('UploadFiles');

        $fModel = $this->gadget->model->load('Files');
        $fModelAdmin = $this->gadget->model->loadAdmin('Files');
        $post = $this->gadget->request->fetch(
            array('path', 'file_title', 'file_description', 'file_fast_url', 'oldname', 'extra_params'),
            'post'
        );
        $uploaddir = $fModel->GetFileBrowserRootDir() . $post['path'];

        require_once PEAR_PATH. 'File/Util.php';
        $uploaddir = File_Util::realpath($uploaddir) . '/';

        if (!File_Util::pathInRoot($uploaddir, $fModel->GetFileBrowserRootDir())) {
            $this->gadget->session->push(Jaws::t('ERROR_UPLOAD'), RESPONSE_ERROR);
        } else {
            $res = Jaws_FileManagement_File::uploadFiles($_FILES, $uploaddir, '');
            if (Jaws_Error::IsError($res)) {
                $this->gadget->session->push($res->getMessage(), RESPONSE_ERROR);
            } elseif (empty($res)) {
                $this->gadget->session->push(Jaws::t('ERROR_UPLOAD_4'), RESPONSE_ERROR);
            } else {
                $post['oldname'] = preg_replace('/[^[:alnum:]_\.\-]*/', '', $post['oldname']);
                if (!empty($post['oldname']) && ($res['uploadfile'][0]['host_filename'] != $post['oldname'])) {
                    $fModelAdmin->Delete($post['path'], $post['oldname']);
                }
                $fModelAdmin->UpdateDBFileInfo(
                    $post['path'],
                    $res['uploadfile'][0]['host_filename'],
                    empty($post['file_title'])? $res['uploadfile'][0]['user_filename'] : $post['file_title'],
                    $post['file_description'],
                    $post['file_fast_url'],
                    $post['oldname']
                );
            }
        }

        if (empty($post['extra_params'])) {
            return Jaws_Header::Location(BASE_SCRIPT . '?reqGadget=FileBrowser&reqAction=Files&path=' . $post['path']);
        } else {
            return Jaws_Header::Location(BASE_SCRIPT . '?reqGadget=FileBrowser&reqAction=BrowseFile&path=' . $post['path'] . html_entity_decode($post['extra_params']));
        }
    }


    /**
     * Browses for the files & directories on the server
     *
     * @access  public
     * @return  string  XHTML template content for browing file
     */
    function BrowseFile()
    {
        $path = $this->gadget->request->fetch('path', 'get');
        $path = empty($path)? '/' : $path;

        $tpl = $this->gadget->template->loadAdmin('BrowseFile.html');
        $tpl->SetBlock('browse');

        $tpl->SetVariable('page-title', $this->gadget->title);
        $tpl->SetVariable('incompleteFields', Jaws::t('ERROR_INCOMPLETE_FIELDS'));
        $tpl->SetVariable('confirmFileDelete', $this::t('CONFIRM_DELETE_FILE'));
        $tpl->SetVariable('confirmDirDelete', $this::t('CONFIRM_DELETE_DIR'));

        $dir = Jaws::t('LANG_DIRECTION');
        $tpl->SetVariable('.dir', ($dir == 'rtl')? '.' . $dir : '');

        // TODO set default value for change page address to correct location after uploading file
        $extraParams = '&amp;';
        $editor = $this->app->getEditor();
        if ($editor === 'TinyMCE') {
            $tpl->SetBlock('browse/script');
            $tpl->ParseBlock('browse/script');
        } elseif ($editor === 'CKEditor') {
            $getParams = $this->gadget->request->fetch(array('CKEditor', 'CKEditorFuncNum', 'langCode'), 'get');
            $extraParams = '&amp;CKEditor='.$getParams['CKEditor'].
                '&amp;CKEditorFuncNum='.$getParams['CKEditorFuncNum'].
                '&amp;langCode='.$getParams['langCode'];
            $tpl->SetVariable('ckFuncIndex', $getParams['CKEditorFuncNum']);
        }

        if ($this->gadget->GetPermission('UploadFiles')) {
            $tpl->SetBlock("browse/upload_file");

            $tpl->SetVariable('path', $path);
            $tpl->SetVariable('extra_params', $extraParams);
            $tpl->SetVariable('lbl_file_upload', $this::t('UPLOAD_FILE'));

            $title =& Piwi::CreateWidget('Entry', 'file_title', '');
            $title->SetStyle('width: 200px;');
            $tpl->SetVariable('lbl_file_title', Jaws::t('TITLE'));
            $tpl->SetVariable('file_title', $title->Get());

            $uploadfile =& Piwi::CreateWidget('FileEntry', 'uploadfile', '');
            $uploadfile->SetID('uploadfile');
            $tpl->SetVariable('lbl_filename', $this::t('FILENAME'));
            $tpl->SetVariable('uploadfile', $uploadfile->Get());

            $btnSave =& Piwi::CreateWidget('Button', 'btn_upload_file', $this::t('UPLOAD_FILE'), STOCK_SAVE);
            $btnSave->AddEvent(ON_CLICK, "javascript:saveFile();");
            $tpl->SetVariable('btn_upload_file', $btnSave->Get());

            $tpl->ParseBlock("browse/upload_file");
        }

        $fModel = $this->gadget->model->load('Files');
        $dModel = $this->gadget->model->load('Directory');
        $pathArr = $dModel->GetCurrentRootDir($path);
        if (!Jaws_Error::IsError($pathArr)) {
            foreach ($pathArr as $_path => $dir)
            {
                if (!empty($dir) && $_path[0] == '/') {
                    $_path = substr($_path, 1);
                }
                $url = BASE_SCRIPT . '?reqGadget=FileBrowser&reqAction=BrowseFile&path=' . $_path;
                if (empty($_path)) {
                    $link =& Piwi::CreateWidget('Link', $this::t('ROOT'), $url . '/' . $extraParams);
                    $tpl->SetVariable('root', $link->Get());
                } else {
                    if ($_path == $path) {
                        $link = Piwi::CreateWidget('StaticEntry', $dir);
                    } else {
                        $link = Piwi::CreateWidget('Link', $dir, $url);
                    }
                    $tpl->SetBlock('browse/path');
                    $tpl->SetVariable('directory', $link->Get());
                    $tpl->ParseBlock('browse/path');
                }
            }
        }

        $tpl->SetVariable('lbl_location', $this::t('LOCATION'));
        $tpl->SetVariable('lbl_file_name', $this::t('FILENAME'));
        $tpl->SetVariable('lbl_file_size', $this::t('SIZE'));
        $tpl->SetVariable('lbl_action', Jaws::t('ACTIONS'));

        $files = $dModel->ReadDir($path);
        if (!Jaws_Error::IsError($files)) {
            foreach ($files as $file) {
                $tpl->SetBlock('browse/file');

                // Icon
                $icon =& Piwi::CreateWidget('Image', $file['mini_icon']);
                $icon->SetID('');
                $tpl->SetVariable('icon', $icon->Get());

                // Directory / File
                if ($file['is_dir']) {
                    $url = BASE_SCRIPT. '?reqGadget=FileBrowser&reqAction=BrowseFile&path='. $file['relative']. $extraParams;
                    $link =& Piwi::CreateWidget('Link', $file['filename'], $url);
                    $link->SetID('');
                    $link->SetTitle($file['title']);
                    $tpl->SetVariable('file_name', $link->Get());

                    if ($this->gadget->GetPermission('ManageDirectories')) {
                        $link =& Piwi::CreateWidget('Link', Jaws::t('DELETE'),
                            "javascript:deleteDir('" . $file['filename'] . "');",
                            STOCK_DELETE);
                        $tpl->SetVariable('action', $link->Get());
                    }


                } else {
                    if (empty($file['id'])) {
                        $furl = Jaws_XSS::filter($file['url']);
                    } else {
                        $fid = empty($file['fast_url'])? $file['id'] : Jaws_XSS::filter($file['fast_url']);
                        $furl = $this->gadget->urlMap('Download', array('id' => $fid));
                    }

                    $link =& Piwi::CreateWidget('Link',
                        $file['filename'],
                        "javascript:selectFile('$furl', '{$file['title']}', '{$file['filename']}', '$editor')");
                    $tpl->SetVariable('file_name', $link->Get());

                    if ($this->gadget->GetPermission('ManageFiles')) {
                        $link =& Piwi::CreateWidget('Link', Jaws::t('DELETE'),
                            "javascript:deleteFile('" . $file['filename'] . "');",
                            STOCK_DELETE);
                        $tpl->SetVariable('action', $link->Get());
                    }

                }

                // File Size
                $tpl->SetVariable('file_size', $file['size']);
                $tpl->ParseBlock('browse/file');
            }
        }

        $tpl->ParseBlock('browse');
        return $tpl->Get();
    }

    /**
     * Delete a file in text editor mode
     *
     * @access  public
     * @return  void
     */
    function DeleteFile()
    {
        $this->gadget->CheckPermission('ManageFiles');

        $model = $this->gadget->model->loadAdmin('Files');
        $post = $this->gadget->request->fetch(array('path', 'selected_item', 'extra_params'), 'post');

        if ($model->Delete($post['path'], $post['selected_item'])) {
            $model->DeleteDBFileInfo($post['path'], $post['selected_item']);
        }

        return Jaws_Header::Location(BASE_SCRIPT . '?reqGadget=FileBrowser&reqAction=BrowseFile&path=' . $post['path'] . html_entity_decode($post['extra_params']));
    }

}